@@ -24,7 +24,8 @@ from gi.repository import Gtk
 
 import cups
 import os
-import tempfile
+from tempfile import NamedTemporaryFile
+import datetime
 import time
 from timedops import TimedOperation
 from .base import *
@@ -37,7 +38,15 @@ except:
 class ErrorLogFetch(Question):
     def __init__ (self, troubleshooter):
         Question.__init__ (self, troubleshooter, "Error log fetch")
-        troubleshooter.new_page (Gtk.Label (), self)
+        page = self.initial_vbox (_("Retrieve Journal Entries"),
+                                  _("No system journal entries were found. "
+                                    "This may be because you are not an "
+                                    "administrator. To fetch journal entries "
+                                    "please run this command:"))
+        self.entry = Gtk.Entry ()
+        self.entry.set_editable (False)
+        page.pack_start (self.entry, False, False, 0)
+        troubleshooter.new_page (page, self)
         self.persistent_answers = {}
 
     def display (self):
@@ -46,6 +55,7 @@ class ErrorLogFetch(Question):
         self.answers = {}
         checkpoint = answers.get ('error_log_checkpoint')
         cursor = answers.get ('error_log_cursor')
+        timestamp = answers.get ('error_log_timestamp')
 
         if ('error_log' in self.persistent_answers or
             'journal' in self.persistent_answers):
@@ -56,23 +66,24 @@ class ErrorLogFetch(Question):
             prompt = c._get_prompt_allowed ()
             c._set_prompt_allowed (False)
             c._connect ()
-            (tmpfd, tmpfname) = tempfile.mkstemp ()
-            os.close (tmpfd)
-            success = False
-            try:
-                c.getFile ('/admin/log/error_log', tmpfname)
-                success = True
-            except cups.HTTPError:
+            with tempfile.NamedTemporaryFile (delete=False) as tmpf:
+                success = False
                 try:
-                    os.remove (tmpfname)
-                except OSError:
-                    pass
+                    c.getFile ('/admin/log/error_log', tmpf.file)
+                    success = True
+                except cups.HTTPError:
+                    try:
+                        os.remove (tmpf.file)
+                    except OSError:
+                        pass
+
+                c._set_prompt_allowed (prompt)
+                if success:
+                    return tmpf.file
 
-            c._set_prompt_allowed (prompt)
-            if success:
-                return tmpfname
             return None
 
+        now = datetime.datetime.fromtimestamp (time.time ()).strftime ("%F %T")
         self.authconn = self.troubleshooter.answers['_authenticated_connection']
         if 'error_log_debug_logging_set' in answers:
             try:
@@ -124,7 +135,7 @@ class ErrorLogFetch(Question):
 
             r = journal.Reader ()
             r.seek_cursor (cursor)
-            r.add_match (_COMM="cupsd")
+            r.add_match (_SYSTEMD_UNIT="cups.service")
             self.answers['journal'] = [journal_format (x) for x in r]
 
         if checkpoint != None:
@@ -139,6 +150,14 @@ class ErrorLogFetch(Question):
                 os.remove (tmpfname)
                 self.answers = { 'error_log': [x.strip () for x in lines] }
 
+        if (len (self.answers.get ('journal', [])) +
+            len (self.answers.get ('error_log', []))) == 0:
+            cmd = ("su -c 'journalctl -u cups.service "
+                   "--since=\"%s\" --until=\"%s\"' > troubleshoot-logs.txt" %
+                   (answers['error_log_timestamp'], now))
+            self.entry.set_text (cmd)
+            return True
+
         return False
 
     def collect_answer (self):
